# Rotary Position Embeddings (RoPE)

RoPE kernels for position encoding, used in LLaMA, Mistral, Qwen, and most modern LLMs.

## Functions

::: rotalabs_accel.kernels.rope.apply_rope

::: rotalabs_accel.kernels.rope.rope_torch

::: rotalabs_accel.kernels.rope.build_rope_cache

## Classes

::: rotalabs_accel.kernels.rope.RotaryEmbedding
